/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

package com.sun.ts.tests.securityapi.idstore.ldap.useforgroup;

import static javax.security.enterprise.identitystore.CredentialValidationResult.INVALID_RESULT;
import static javax.security.enterprise.identitystore.CredentialValidationResult.NOT_VALIDATED_RESULT;
import static javax.security.enterprise.identitystore.IdentityStore.ValidationType.PROVIDE_GROUPS;
import static javax.security.enterprise.identitystore.IdentityStore.ValidationType.VALIDATE;
import static java.util.Arrays.asList;

import java.util.HashMap;
import java.util.HashSet;

import java.util.Map;
import java.util.Set;
import java.util.EnumSet;
import java.util.List;
import java.util.ArrayList;

import javax.annotation.PostConstruct;
import javax.enterprise.context.RequestScoped;
import javax.security.enterprise.identitystore.CredentialValidationResult;
import javax.security.enterprise.identitystore.IdentityStore;
import javax.security.enterprise.identitystore.IdentityStore.ValidationType;
import javax.security.enterprise.credential.Credential;
import javax.security.enterprise.credential.UsernamePasswordCredential;
import javax.security.enterprise.CallerPrincipal;


/*
 * 
 */
@RequestScoped
public class IdentityStore2 implements IdentityStore {

	private Map<String, String> userPwd;
	private Map<String, Set<String>> userGroup;
	
	@PostConstruct
	public void init() {
	    userPwd = new HashMap<>();
	    userPwd.put("tom", "secret1");
		userPwd.put("emma","secret12");
		userPwd.put("bob", "secret13");
		
		userGroup = new HashMap<>();		
		userGroup.put("tom", new HashSet<>(asList( "Administrator2", "Manager2" )));
		userGroup.put("emma",new HashSet<>(asList( "Administrator2", "Employee2")));
		userGroup.put("bob", new HashSet<>(asList( "Administrator2")));		
	}
	
	@Override
	public CredentialValidationResult validate(Credential credential) {
	    CredentialValidationResult result;
	
	    
	    
	    if (credential instanceof UsernamePasswordCredential) {
		    UsernamePasswordCredential usernamePassword = (UsernamePasswordCredential) credential;
		    String caller = usernamePassword.getCaller();
		    String expectedPW = userPwd.get(caller);
		
		    if (expectedPW != null && expectedPW.equals(usernamePassword.getPasswordAsString())) {		    	
		        result = new CredentialValidationResult(caller, userGroup.get(caller));
		    } else {
		        result = INVALID_RESULT;
		    }
		   		      
		} else {
			result = NOT_VALIDATED_RESULT;
		}
	
	    System.out.println("IDStore1:validate..." + result.getStatus().name());
	    return result;
	}
	
	@Override
	public Set<String> getCallerGroups(CredentialValidationResult validationResult) {		
		System.out.println("IDStore1:getCallerGroups...");
		Set<String> groups = new HashSet<String>();
		groups.add("IDStore2:getCallerGroups");        
		groups.addAll(userGroup.get(validationResult.getCallerPrincipal().getName()));
	    return groups;
	}
	
	@Override
	public int priority(){
		int priority = 200;
		return priority;
	}
	
	
	@Override
	public Set<ValidationType> validationTypes() {
		return EnumSet.of(PROVIDE_GROUPS);
	}

}
